@@ -4,7 +4,6 @@ import { useFormContext } from 'react-hook-form';
 import { CoreApp } from '@grafana/data';
 import { config } from '@grafana/runtime';
 import { DataQuery } from '@grafana/schema';
-import { contextSrv } from 'app/core/services/context_srv';
 import { QueryLibraryContext, QueryLibraryDrawerOptions } from 'app/features/explore/QueryLibrary/QueryLibraryContext';
 
 import { SavedQuery, type OnSelectQueryType } from '../../features/explore/QueryLibrary/types';
@@ -16,6 +15,7 @@ import { QueryLibraryEditingHeader } from './QueryLibraryEditingHeader';
 import { SavedQueryButtons } from './SavedQueryButtons';
 import { QueryLibraryEventsPropertyMap, QueryLibraryTab } from './types';
 import { getUserStorageFavorites, setUserStorageFavorites } from './utils/favorites';
+import { hasWritePermissions } from './utils/identity';
 
 import { getQueryLibraryDrawerAction, getQueryLibraryRenderContext } from './index';
 
@@ -113,8 +113,8 @@ export function QueryLibraryContextProvider({ children }: PropsWithChildren) {
 
   const openDrawer = useCallback(
     ({ datasourceFilters, onSelectQuery, options, query }: QueryLibraryDrawerOptions) => {
-      // this means the user is trying to add a query but is a viewer
-      if (!!query && !contextSrv.isEditor) {
+      // this means the user is trying to save a query but doesn't have write permission
+      if (!!query && !hasWritePermissions()) {
         return;
       }
 
@@ -168,6 +168,7 @@ export function QueryLibraryContextProvider({ children }: PropsWithChildren) {
       // Reset the callback to no-op function
       setOnSelectQuery(() => () => {});
       setNewQuery(undefined);
+      setIsEditingQuery(false);
       setIsDrawerOpen(false);
       setCloseGuard(() => () => true);
 
@@ -175,7 +176,6 @@ export function QueryLibraryContextProvider({ children }: PropsWithChildren) {
       setHighlightedQuery(undefined);
 
       if (isEditingQuery) {
-        setIsEditingQuery(false);
         QueryDetailsFormMethods?.reset();
 
         triggerAnalyticsEvent(QueryLibraryInteractions.queryLibraryClosedToEditQueryInExplore);
@@ -237,7 +237,8 @@ export function QueryLibraryContextProvider({ children }: PropsWithChildren) {
         app?: CoreApp,
         onUpdateSuccess?: () => void,
         onSelectQuery?: (query: DataQuery) => void,
-        datasourceFilters?: string[]
+        datasourceFilters?: string[],
+        parentRef?: React.RefObject<HTMLElement | null>
       ) => (
         <SavedQueryButtons
           query={query}
@@ -245,6 +246,7 @@ export function QueryLibraryContextProvider({ children }: PropsWithChildren) {
           onUpdateSuccess={onUpdateSuccess}
           onSelectQuery={onSelectQuery}
           datasourceFilters={datasourceFilters || []}
+          parentRef={parentRef}
         />
       ),
       setActiveTab,
