@@ -2,7 +2,7 @@ import { render, screen } from '@testing-library/react';
 import userEvent from '@testing-library/user-event';
 import { TestProvider } from 'test/helpers/TestProvider';
 
-import { reportInteraction } from '@grafana/runtime';
+import { config, reportInteraction } from '@grafana/runtime';
 import { getRouteComponentProps } from 'app/core/navigation/mocks/routeProps';
 import { addRootReducer } from 'app/store/configureStore';
 
@@ -98,7 +98,7 @@ describe('FormatReport', () => {
     await userEvent.click(screen.getByRole('button', { name: /next:/i }));
     expect(mockUpdate).toHaveBeenCalledWith({
       ...blankReport,
-      options: { ...blankReport.options, orientation: 'portrait', layout: 'simple' },
+      options: { ...blankReport.options, orientation: 'portrait', layout: 'simple', csvEncoding: 'utf-8-bom' },
       formats: [ReportFormat.PDF, ReportFormat.Image, ReportFormat.CSV],
     });
   });
@@ -119,7 +119,7 @@ describe('FormatReport', () => {
     await userEvent.click(screen.getByRole('button', { name: /next:/i }));
     expect(mockUpdate).toHaveBeenCalledWith({
       ...blankReport,
-      options: { ...blankReport.options, orientation: 'portrait', layout: 'simple' },
+      options: { ...blankReport.options, orientation: 'portrait', layout: 'simple', csvEncoding: 'utf-8-bom' },
       formats: [ReportFormat.PDF],
     });
   });
@@ -151,4 +151,48 @@ describe('FormatReport', () => {
       expect(reportInteraction).toHaveBeenCalledWith('reports_pdf_table_attach_separate', { checked: false });
     });
   });
+
+  describe('CSV encoding', () => {
+    it('should not display CSV encoding field when feature toggle is disabled', async () => {
+      config.featureToggles.reportingCsvEncodingOptions = false;
+      setup();
+
+      await userEvent.click(screen.getByRole('checkbox', { name: /attach a csv file of table panel data/i }));
+
+      expect(screen.queryByText(/csv encoding/i)).not.toBeInTheDocument();
+      expect(screen.queryByText(/choose encoding format for csv files/i)).not.toBeInTheDocument();
+    });
+
+    it('should not display CSV encoding field when CSV is not selected', () => {
+      config.featureToggles.reportingCsvEncodingOptions = true;
+      setup();
+
+      expect(screen.queryByText(/csv encoding/i)).not.toBeInTheDocument();
+      expect(screen.queryByText(/choose encoding format for csv files/i)).not.toBeInTheDocument();
+    });
+
+    it('should display CSV encoding field when CSV is selected and feature toggle is enabled', async () => {
+      config.featureToggles.reportingCsvEncodingOptions = true;
+      setup();
+
+      await userEvent.click(screen.getByRole('checkbox', { name: /attach a csv file of table panel data/i }));
+
+      expect(await screen.findByText(/csv encoding/i)).toBeInTheDocument();
+      expect(screen.getByText(/choose encoding format for csv files/i)).toBeInTheDocument();
+    });
+
+    it('should submit form with default CSV encoding when selected', async () => {
+      config.featureToggles.reportingCsvEncodingOptions = true;
+      setup();
+
+      await userEvent.click(screen.getByRole('checkbox', { name: /attach a csv file of table panel data/i }));
+      await userEvent.click(screen.getByRole('button', { name: /next:/i }));
+
+      expect(mockUpdate).toHaveBeenCalledWith({
+        ...blankReport,
+        options: { ...blankReport.options, csvEncoding: 'utf-8' },
+        formats: [ReportFormat.PDF, ReportFormat.CSV],
+      });
+    });
+  });
 });
